@@ -10,17 +10,8 @@ function(x = Sys.Date(),
     
     start <- floor_date( x, unit = "month" ) - months(n)
     stop  <- start + months(n + ifelse( include_current, 1, 0)) - days(1)
-    sequence <- seq.Date(from = start, to = stop, by = "day")
     
-    pular <- ifelse( n > 1, "s", "")
-    
-    nname <- paste0("month", pular)
-    out   <- list(start  = start,
-                  end    = stop,
-                  sequence = sequence,
-                  length   =  length(sequence),
-                  values = paste(n, nname, "ago from", x))
-    class(out) <- "tpr"
+    out   <- custom_period(start, stop)
     
     part <- match.arg(part)
     
